@@ -3,17 +3,17 @@ from insightsearch.data_clean import  DataframeClean
 
 
 class DFvalid:
-    def __init__(self, df, column_name, date_column,bert):
+    def __init__(self, df, column_name, date_column,vader):
         self.df = pd.read_csv(df)
         self.column_name = str(column_name)
-        self.date_column = str(date_column)
-        self.bert=bert
+        self.date_column = date_column
+        self.vader=vader
         """
         parm df :df is the dataframe that contains review column , df doenot need all rows should be string. Datatypes other than str will be removed
         param column_name = Name of the column that contains review text 
 
         """
-        DataframeClean.__init__(self, self.df, self.column_name, self.date_column,self.bert)
+        DataframeClean.__init__(self, self.df, self.column_name, self.date_column,self.vader)
         # chechking df is a pd.DataFrame
         if self.df is not None:
             if isinstance(self.df, pd.DataFrame) != True:
@@ -29,7 +29,7 @@ class DFvalid:
             else:
                 print("Try to mention a column name where your reviews stored")
 
-            if self.date_column is not None:
+            if self.date_column != None:
                 if isinstance(self.date_column, str) != True:
                     raise AttributeError("The dataframe name is not string ")
                 if self.date_column not in self.df.columns:
@@ -37,6 +37,6 @@ class DFvalid:
                         "Your mentioned name in date column does not exists in your uploaded dataframe"
                     )
             else:
-                print("Try to mention a column name where dates stored")
+                pass
         else:
             print("There is no data frame")
